package com.ruoyi.system.controller;

import com.ruoyi.system.domain.dto.UpdateBaseParams;
import com.ruoyi.system.domain.dto.DeploySSLParams;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.ruoyi.common.core.utils.StringUtils;
import org.springframework.web.bind.annotation.PathVariable;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.github.pagehelper.PageInfo;
import java.util.List;
import com.ruoyi.common.core.utils.bean.BeanUtils;
import com.ruoyi.system.domain.dto.SnServerTemplateListDto;
import com.ruoyi.common.core.web.page.TableDataInfo;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.RequestBody;
import com.ruoyi.system.domain.SnServerTemplate;
import com.ruoyi.system.service.ISnTemplateService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISnServerTemplateService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/SnServerTemplate" })
public class SnServerTemplateController extends BaseController
{
    @Autowired
    private ISnServerTemplateService snServerTemplateService;
    @Autowired
    private ISnTemplateService snTemplateService;
    
    @PostMapping({ "/getOwnLast" })
    public AjaxResult getOwnLast(@RequestBody final SnServerTemplate params) {
        if (params.getServerId() == null) {
            return AjaxResult.error("参数不能为空");
        }
        return this.snServerTemplateService.getOwnLast(params.getServerId());
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SnServerTemplate snServerTemplate) {
        this.startPage();
        final List<SnServerTemplate> list = this.snServerTemplateService.selectSnServerTemplateList(snServerTemplate);
        final TableDataInfo rspData = new TableDataInfo();
        rspData.setCode(200);
        rspData.setRows(BeanUtils.copyList((List)list, (Class)SnServerTemplateListDto.class));
        rspData.setMsg("查询成功");
        rspData.setTotal(new PageInfo((List)list).getTotal());
        return rspData;
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:export" })
    @Log(title = "导出客户端", businessType = BusinessType.EXPORT)
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SnServerTemplate snServerTemplate) {
        final List<SnServerTemplate> list = this.snServerTemplateService.selectSnServerTemplateList(snServerTemplate);
        final ExcelUtil<SnServerTemplate> util = (ExcelUtil<SnServerTemplate>)new ExcelUtil((Class)SnServerTemplate.class);
        util.exportExcel(response, (List)list, "服务器使用模板数据");
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:query" })
    @GetMapping({ "/{id}" })
    public AjaxResult getInfo(@PathVariable("id") final Long id) {
        return this.success((Object)this.snServerTemplateService.selectSnServerTemplateById(id));
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:add" })
    @Log(title = "新增客户端", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody final SnServerTemplate snServerTemplate) {
        if (snServerTemplate.getTemplateId() == null) {
            return this.error("请先选择模板");
        }
        if (snServerTemplate.getServerId() == null) {
            return this.error("请先选择服务器");
        }
        if (StringUtils.isEmpty(snServerTemplate.getDomain())) {
            return this.error("请填写部署域名");
        }
        if (snServerTemplate.getDomain().startsWith("http")) {
            return this.error("域名不能包含http://或https://前缀");
        }
        if (snServerTemplate.getDomain().contains("/")) {
            return this.error("域名不能包含/");
        }
        return this.snServerTemplateService.insertSnServerTemplate(snServerTemplate);
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:edit" })
    @Log(title = "修改客户端", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody final SnServerTemplate snServerTemplate) {
        return this.toAjax(this.snServerTemplateService.updateSnServerTemplate(snServerTemplate));
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:remove" })
    @Log(title = "删除客户端", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{ids}" })
    public AjaxResult remove(@PathVariable final Long[] ids) {
        return this.toAjax(this.snServerTemplateService.deleteSnServerTemplateByIds(ids));
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:changeDomain" })
    @Log(title = "更换客户端域名", businessType = BusinessType.OTHER)
    @PostMapping({ "/changeDomain" })
    public AjaxResult changeDomain(@RequestBody final SnServerTemplate snServerTemplate) {
        if (StringUtils.isEmpty(snServerTemplate.getDomain())) {
            return this.error("请先填写域名");
        }
        if (snServerTemplate.getId() == null) {
            return this.error("服务器模板不能为空");
        }
        return this.snServerTemplateService.changeDomain(snServerTemplate);
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:deployDomainSSL" })
    @Log(title = "部署客户端域名ssl证书", businessType = BusinessType.OTHER)
    @PostMapping({ "/deployDomainSSL" })
    public AjaxResult deployDomainSSL(@RequestBody final DeploySSLParams params) {
        if (params.getId() == null) {
            return this.error("客户端ID不能为空");
        }
        if (params.getType() == null) {
            return this.error("证书类型不能为空");
        }
        if (params.getType() != 1 && params.getType() != 2) {
            return this.error("证书类型有误");
        }
        if (params.getType() == 2 && StringUtils.isEmpty(params.getSslKey())) {
            return this.error("请先填写域名");
        }
        if (params.getType() == 2 && StringUtils.isEmpty(params.getSslPem())) {
            return this.error("请先填写域名");
        }
        return this.snServerTemplateService.deployDomainSSL(params);
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:updateUI" })
    @Log(title = "更新客户端UI包", businessType = BusinessType.OTHER)
    @PostMapping({ "/updateUI" })
    public AjaxResult updateUI(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("客户端ID不能为空");
        }
        return this.snServerTemplateService.updateUI(params);
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:updateUI" })
    @PostMapping({ "/haveUpdate" })
    public AjaxResult haveUpdate(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerTemplateService.haveUpdate(params);
    }
    
    @RequiresPermissions({ "system:SnServerTemplate:updateUI" })
    @Log(title = "更新所有客户端UI包", businessType = BusinessType.OTHER)
    @PostMapping({ "/updateAllUI" })
    public AjaxResult updateAllUI(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerTemplateService.updateAllUI(params);
    }
}
